==> abtesting-hooks-1.11.0.tgz: package/lib/useExperiment/index.js <==
import { useContext } from 'react';
import { getExperimentContext as getExperimentContextFromPackage } from '@s-ui/abtesting-optimizely-x';
import useExperimentCore from '../useExperimentCore'; // Fallback object in case the hook is used in some point of the hierarchy
// that is not wrapped by OptimizelyXExperiment component (which is the
// provider of the actual context). This way we mainly avoid trying to access
// properties from undefined when no experiment context is present.

var NON_WRAPPED_BY_CONTEXT_PROVIDER_FALLBACK_OBJECT = {
  isDefault: true,
  isWrapped: false
};
export default (function (params) {
  if (params === void 0) {
    params = {};
  }

  var isCoreRunner = params.experimentId; // ACT AS AN EXPERIMENT CORE RUNNER
  // - if the required params are passed, run a new experiment here

  if (isCoreRunner) {
    var _useExperimentCore = useExperimentCore(params),
        _experimentData = _useExperimentCore.experimentData;

    return _experimentData;
  } // ACT AS AN EXPERIMENT CONTEXT CONSUMER
  // - return data from the context of an already running experiment


  var _params = params,
      getExperimentContext = _params.getExperimentContext;
  var contextGetter = getExperimentContext || getExperimentContextFromPackage;
  var experimentName = typeof params === 'string' ? params : params.name;
  var ExperimentContext = contextGetter(experimentName);
  var experimentData = useContext(ExperimentContext) || NON_WRAPPED_BY_CONTEXT_PROVIDER_FALLBACK_OBJECT;
  return experimentData;
});

==> abtesting-hooks-1.12.0.tgz: package/lib/useExperiment/index.js <==
import { useContext } from 'react';
import { getExperimentContext as getExperimentContextFromPackage } from '@s-ui/abtesting-optimizely-x';
import useExperimentCore from '../useExperimentCore';

// Fallback object in case the hook is used in some point of the hierarchy
// that is not wrapped by OptimizelyXExperiment component (which is the
// provider of the actual context). This way we mainly avoid trying to access
// properties from undefined when no experiment context is present.
var NON_WRAPPED_BY_CONTEXT_PROVIDER_FALLBACK_OBJECT = {
  isDefault: true,
  isWrapped: false
};
export default (function (params) {
  if (params === void 0) {
    params = {};
  }
  var isCoreRunner = params.experimentId;

  // ACT AS AN EXPERIMENT CORE RUNNER
  // - if the required params are passed, run a new experiment here
  if (isCoreRunner) {
    var _useExperimentCore = useExperimentCore(params),
      _experimentData = _useExperimentCore.experimentData;
    return _experimentData;
  }

  // ACT AS AN EXPERIMENT CONTEXT CONSUMER
  // - return data from the context of an already running experiment
  var _params = params,
    getExperimentContext = _params.getExperimentContext;
  var contextGetter = getExperimentContext || getExperimentContextFromPackage;
  var experimentName = typeof params === 'string' ? params : params.name;
  var ExperimentContext = contextGetter(experimentName);
  var experimentData = useContext(ExperimentContext) || NON_WRAPPED_BY_CONTEXT_PROVIDER_FALLBACK_OBJECT;
  return experimentData;
});
